@@ -1,5 +1,5 @@
 package PAR;
-$PAR::VERSION = '0.950';
+$PAR::VERSION = '0.951';
 
 use 5.006;
 use strict;
@@ -13,7 +13,7 @@ PAR - Perl Archive Toolkit
 
 =head1 VERSION
 
-This document describes version 0.950 of PAR, released August 1, 2006.
+This document describes version 0.951 of PAR, released August 12, 2006.
 
 =head1 SYNOPSIS
 
@@ -106,7 +106,11 @@ If you have L<PAR::Repository::Client> installed, you can do this:
 
 And PAR will fetch any modules you don't have from the specified PAR
 repository. For details on how this works, have a look at the SEE ALSO
-section below.
+section below. Finally, you can combine the C<run> and C<repository>
+options to run an application directly from a repository!
+
+  use PAR { repository => 'http://foo/bar/', run => 'my_app' };
+  # Will not reach this point as we executed my_app,
 
 =head1 DESCRIPTION
 
@@ -352,12 +356,22 @@ sub _import_hash_ref {
     }
     else {
         # Deal with repositories elsewhere
-        return(_import_repository($opt));
+        my $client = _import_repository($opt);
+        return() if not $client;
+
+        if (defined $opt->{run}) {
+            # run was specified
+            # run the specified script from the repository
+            $client->run_script( $opt->{run} );
+            return 1;
+        }
+        
+        return 1;
     }
 
     # run was specified
     # run the specified script from inside the PAR file.
-    if (exists $opt->{run} and defined $opt->{run}) {
+    if (defined $opt->{run}) {
         my $script = $opt->{run};
         require PAR::Heavy;
         PAR::Heavy::_init_dynaloader();
@@ -385,6 +399,7 @@ sub _import_hash_ref {
 
 # This sub is invoked by _import_hash_ref if a {repository}
 # option is found
+# Returns the repository client object on success.
 sub _import_repository {
     my $opt = shift;
     my $url = $opt->{repository};
@@ -395,7 +410,7 @@ sub _import_repository {
     }
     my $obj = PAR::Repository::Client->new(uri => $url);
     push @RepositoryObjects, $obj;
-    return 1;
+    return $obj;
 }
 
 sub _first_member {
@@ -485,7 +500,7 @@ sub find_par_last {
     return $rv if defined $rv;
 
     # No repositories => return
-    return() if not @RepositoryObjects;
+    return $rv if not @RepositoryObjects;
 
     my $module = $args[1];
     $module =~ s/\.pm$//;
@@ -496,10 +511,18 @@ sub find_par_last {
             return _find_par_internals([$PAR_INC_LAST[-1]], @args);
         }
     }
-    return();
+    return $rv;
 }
 
 
+# This is a conjunction of the early find_par and the late
+# find_par_last. It's called by PAR::Heavy for Dynaloader stuff.
+sub _find_par_any {
+    return _find_par_internals([@PAR_INC, @PAR_INC_LAST], @_);
+}
+
+
+
 # This routine implements loading modules from PARs
 # both for loading PARs preferably or as fallback.
 # To distinguish the cases, the first parameter should
