@@ -740,9 +740,9 @@ sub pack_manifest_hash {
         @{ $opt->{F} || ($verbatim ? [] : ['PodStrip']) },
       );
 
+    (my $privlib = $Config{privlib}) =~ s{\\}{/}g;
+    (my $archlib = $Config{archlib}) =~ s{\\}{/}g;
     foreach my $pfile (sort grep length $map{$_}, keys %map) {
-        (my $privlib = $Config{privlib}) =~ s{\\}{/}g;
-        (my $archlib = $Config{archlib}) =~ s{\\}{/}g;
         next if !$opt->{B} and (
             ($map{$pfile} eq "$privlib/$pfile") or
             ($map{$pfile} eq "$archlib/$pfile")
@@ -1435,7 +1435,7 @@ my $member = eval { $zip->memberNamed($file) }
                 || $zip->memberNamed("$file.pl")
                 || $zip->memberNamed("script/$file")
                 || $zip->memberNamed("script/$file.pl")
-        or die qq(mail.pl: Can't open perl script "$file": No such file or directory);
+        or die qq(main.pl: Can't open perl script "$file": No such file or directory);
 PAR::_run_member($member, 1);
 
 __MAIN__
